Index: chrome/browser/io_thread.cc |
=================================================================== |
--- chrome/browser/io_thread.cc (revision 51385) |
+++ chrome/browser/io_thread.cc (working copy) |
@@ -138,9 +138,9 @@ |
void IOThread::CleanUp() { |
// If any child processes are still running, terminate them and |
// and delete the ChildProcessHost instances to release whatever |
// IO thread only resources they are referencing. |
- ChildProcessHost::TerminateAll(); |
+ BrowserChildProcessHost::TerminateAll(); |
// Not initialized in Init(). May not be initialized. |
if (predictor_) { |
@@ -138,9 +138,9 @@ |
void IOThread::CleanUp() { |
// If any child processes are still running, terminate them and |
- // and delete the ChildProcessHost instances to release whatever |
+ // and delete the BrowserChildProcessHost instances to release whatever |
// IO thread only resources they are referencing. |